<?php

namespace App\Http\Controllers\Admin;

use Auth;
use App\User;
use App\Category;
use App\SubCategory;
use App\Authors;
use App\Books;
use App\BooksMp3;
use App\Favourite;
use App\PostRatings;
use App\Reports;
use App\PostViewsDownload;

use App\Http\Requests;
use Illuminate\Http\Request;
use Session;
use Intervention\Image\Facades\Image;
use Illuminate\Support\Str; 

class BooksController extends MainAdminController
{
	public function __construct()
    {
		 $this->middleware('auth');
          
    }

    public function list()
    { 
 
        if(Auth::User()->usertype!="Admin" AND Auth::User()->usertype!="Sub_Admin")
        {

            \Session::flash('flash_message', trans('words.access_denied'));

            return redirect('dashboard');
            
        }

        if(isset($_GET['s']))
        {
            $keyword = $_GET['s'];  
            $list = Books::where("title", "LIKE","%$keyword%")->orderBy('title')->paginate(12);

            $list->appends(\Request::only('s'))->links();
        }
        else if(isset($_GET['filter_slider']) AND $_GET['filter_slider']=="yes")
        {
              
            $list = Books::where("featured", "1")->orderBy('id','DESC')->paginate(12);             

            $list->appends(\Request::only('filter_slider'))->links();
        } 
        else if(isset($_GET['cat_id']))
        {
            $cat_id = $_GET['cat_id'];  
            $list = Books::where("cat_id", $cat_id)->orderBy('id','DESC')->paginate(12);     

            $list->appends(\Request::only('cat_id'))->links();
        } 
        else if(isset($_GET['author_id']))
        {
            $author_id = $_GET['author_id'];  
            $list = Books::whereRaw("find_in_set('$author_id',author_ids)")->orderBy('title')->paginate(12);

            $list->appends(\Request::only('author_id'))->links();
        }        
        else
        {
            $list = Books::orderBy('id','DESC')->paginate(12);

        }

        $cat_list = Category::orderBy('category_name')->get();
        $authors_list = Authors::orderBy('name')->get();

        $page_title=trans('words.books_text');

          
        return view('admin.pages.books.list',compact('page_title','list','cat_list','authors_list'));
    }

    public function add()    
    {     
          if(Auth::User()->usertype!="Admin" AND Auth::User()->usertype!="Sub_Admin")
            {

                \Session::flash('flash_message', trans('words.access_denied'));

                return redirect('dashboard');
                
             }  

          $page_title=trans('words.add_book');

          $cat_list = Category::orderBy('category_name')->get();
          $sub_cat_list = SubCategory::orderBy('sub_category_name')->get();
          $authors_list = Authors::orderBy('name')->get();
          
          return view('admin.pages.books.add',compact('page_title','cat_list','sub_cat_list','authors_list'));
        
    }

    public function edit($post_id)    
    {     
          if(Auth::User()->usertype!="Admin" AND Auth::User()->usertype!="Sub_Admin")
            {

                \Session::flash('flash_message', trans('words.access_denied'));

                return redirect('dashboard');
                
             }  

          $page_title=trans('words.edit_book');

          $info = Books::findOrFail($post_id);

          $cat_list = Category::orderBy('category_name')->get();
          $sub_cat_list = SubCategory::where('cat_id',$info->cat_id)->orderBy('sub_category_name')->get();
          $authors_list = Authors::orderBy('name')->get();

          $books_mp3_list = BooksMp3::where('book_id',$post_id)->orderBy('id')->get();
          //dd($books_mp3_list);
         
          return view('admin.pages.books.edit',compact('page_title','info','cat_list','sub_cat_list','authors_list','books_mp3_list'));
        
    }

    public function addnew(Request $request)
    {  
       
       $data =  \Request::except(array('_token')) ;
       
       if(!empty($inputs['id'])){
                
            $rule=array(
            'title' => 'required',
            'category' => 'required'           
                 );
        }
        else
        {
            $rule=array(
                'title' => 'required',
                'category' => 'required',
                'book_image' => 'required'                                 
                    );
        }

        
        $validator = \Validator::make($data,$rule);
 
        if ($validator->fails())
        {
                return redirect()->back()->withErrors($validator->messages());
        } 
        $inputs = $request->all();

        if(!empty($inputs['id'])){
           
            $data_obj = Books::findOrFail($inputs['id']);

        }else{

            $data_obj = new Books;

        }         
        
        $author_ids= isset($inputs['author_ids'])?implode(',', $inputs['author_ids']):'';

        $data_obj->book_access = $inputs['book_access']; 
        $data_obj->title = addslashes($inputs['title']);
        $data_obj->description = addslashes($inputs['description']);
        $data_obj->cat_id = $inputs['category']; 
        $data_obj->sub_cat_id = $inputs['sub_category']; 
        $data_obj->author_ids = $author_ids;
        $data_obj->image = $inputs['book_image'];       
        
        $data_obj->url_type = $inputs['url_type'];

        if($inputs['url_type']=="server_url")
        {
        $data_obj->url = $inputs['book_url_server'];
        }
        else
        {
        $data_obj->url = $inputs['book_url_local'];
        }

        if(isset($inputs['download_enable']))
         {
            $data_obj->download_enable = $inputs['download_enable'];  
          }

        $data_obj->book_on_rent = $inputs['book_on_rent'];

        if($inputs['book_on_rent']==1)
        {
            $data_obj->book_rent_price = $inputs['book_rent_price'];
            $data_obj->book_rent_time = $inputs['book_rent_time'];
        }

        $data_obj->status = $inputs['status']; 

        $data_obj->mp3_type = $inputs['mp3_type'];       
        
        $data_obj->save();

        //MP3 ADD/EDIT
        if(!empty($inputs['id']))
        {
            $book_id = $inputs['id'];
 
        }
        else
        {
            $book_id = $data_obj->id;
 
        }

        //MP3
        if($inputs['mp3_type']=="local")
        {
                $count=count($inputs['mp3_local']);

                //dd($count);exit;

                for($mp3=0; $mp3<$count; $mp3++)
                { 
                    if(isset($inputs['mp3_local_id'][$mp3]))
                    {
                        $mp3_obj = BooksMp3::findOrFail($inputs['mp3_local_id'][$mp3]);

                        $mp3_obj->book_id = $book_id; 
                        $mp3_obj->title = addslashes($inputs['mp3_local_title'][$mp3]);
                        $mp3_obj->duration = $inputs['mp3_local_duration'][$mp3];
                        $mp3_obj->url = $inputs['mp3_local'][$mp3];     
            
                        $mp3_obj->save();
                    }
                    else
                    {
                       if($inputs['mp3_local_title'][$mp3]!="")
                       {
                            $mp3_obj = new BooksMp3;

                            $mp3_obj->book_id = $book_id; 
                            $mp3_obj->title = addslashes($inputs['mp3_local_title'][$mp3]);
                            $mp3_obj->duration = $inputs['mp3_local_duration'][$mp3];
                            $mp3_obj->url = $inputs['mp3_local'][$mp3];     
                
                            $mp3_obj->save();
                       }
                        
                    }
                    
                }
        }
        else
        {
                    $count=count($inputs['mp3_server']);

                    //dd($count);exit;

                    for($mp3=0; $mp3<$count; $mp3++)
                    { 
                        if(isset($inputs['mp3_server_id'][$mp3]))
                        {
                              
                            $mp3_obj = BooksMp3::findOrFail($inputs['mp3_server_id'][$mp3]);

                            $mp3_obj->book_id = $book_id; 
                            $mp3_obj->title = addslashes($inputs['mp3_server_title'][$mp3]);
                            $mp3_obj->duration = $inputs['mp3_server_duration'][$mp3];
                            $mp3_obj->url = $inputs['mp3_server'][$mp3];     
                
                            $mp3_obj->save();
                        }
                        else
                        {
                            if($inputs['mp3_server_title'][$mp3]!="")
                            {
                                $mp3_obj = new BooksMp3;

                                $mp3_obj->book_id = $book_id; 
                                $mp3_obj->title = addslashes($inputs['mp3_server_title'][$mp3]);
                                $mp3_obj->duration = $inputs['mp3_server_duration'][$mp3];
                                $mp3_obj->url = $inputs['mp3_server'][$mp3];     

                                $mp3_obj->save();
                            }
                        }
                    }
        }
 
 
        if(!empty($inputs['id'])){

            \Session::flash('flash_message', trans('words.successfully_updated'));

            return \Redirect::back();
        }else{

            \Session::flash('flash_message', trans('words.added'));

            return \Redirect::back();

        }   
    }
  
}
